use "$Data/EFMS for Analysis District", clear
xtset DistrictId Year
global outvar "*EFMS*"
global Weight ""
global controls= ""


egen StateId=group(StateNREGA)

replace EFMS_Labour=EFMSStartWage==Year 
replace EFMS_Material=EFMSStartMaterial==Year 

foreach item in Labour Material {
foreach time in  "F6." "F5." "F4." "F3." "F2." "L1." "L2." "L3." "L4." "L5." "L6."{
local name=subinstr("`time'",".","",.)
gen `name'EFMS_`item'=`time'EFMS_`item' 
replace `name'EFMS_`item'=0 if missing(`name'EFMS_`item')
}

display "Doing `time'"
 eststo : xtreg Exp`item' F?EFMS_`item' EFMS_`item' L?EFMS_`item'  _IYear* $Weight,fe vce(cluster StateId) 
 }


esttab using "$Tables/Table with District lags and forwards.csv", replace ///
noomitted nogap se nostar wide noparentheses nonumbers
eststo clear


insheet using "$Tables/Table with District lags and forwards.csv", names clear comma


drop if inlist(v1, "_cons", "N", "Standard errors in second column")

rename v1 RHS 
keep if regexm(RHS,"EFMS")==1

gen Time=0 if RHS=="EFMS_Labour" | RHS=="EFMS_Material"
forvalues x=1/5{
replace Time=-`x' if RHS=="F`x'EFMS_Labour" | RHS=="F`x'EFMS_Material"
replace Time=`x' if RHS=="L`x'EFMS_Labour" | RHS=="L`x'EFMS_Material"
}

rename explabour coef_labor
rename v3 se_labor
rename expmaterial coef_material
rename v5 se_material

drop RHS

local new=_N+1
set obs `new'
replace Time=-1 in `new'
foreach var of varlist coef* se*{
replace `var'=0 in `new'
}

foreach item in labor material{
gen bound_10th_`item'=coef_`item'-1.64*se_`item'
gen bound_90th_`item'=coef_`item'+1.64*se_`item'
gen bound_5th_`item'=coef_`item'-1.96*se_`item'
gen bound_95th_`item'=coef_`item'+1.96*se_`item'
}

local counter="a"
foreach item in labor material{
graph twoway (scatter coef_`item' Time) || (rcap bound_5th_`item' bound_95th_`item' Time), xtitle("") xlabel(-4 -3 -2 -1 0 1 2 3 4 , ///
valuelabel labsize(small)) ytitle("Expenditures on `item'") xtitle("Year relative to e-FMS implementation") legend(off) ///
graphregion(color(white)) note("Estimated coefficients and 95% confidence intervals from a linear regression of MGNREGS" ///
 "expenditures (reported in nrega.nic.in) on a dummy equal to one for the year of e-FMS" ///
 "implementation, including five lags and four forwards. The red vertical line indicates" ///
 "the year of e-FMS implementation.") xline(-0.5)
graph export "$Figures/F4`counter'_DiD_EFMS_`item'.pdf", replace
local counter="b"

}

