	

foreach Asset in LogTotalMovable LogTotal{
************************** Quantile Estimates *************************
foreach Posting in All /*Panchayat Block*/{
use "$Data/Asset Declaration Cleaned Anonymized", clear
drop if Batch==0 | Batch==3
egen BlockId=group(District Block)

if "`Posting'"=="Panchayat" |  "`Posting'"=="Block"{
keep if Posting=="`Posting'"
}

if "`Posting'"=="Panchayat"{
	global EmployeeControls="C_*"
}
else{
	global EmployeeControls="C_* _IDes*"
}

preserve
keep BlockId
duplicates drop 
save "$Data/Bootstrap 1", replace
restore

xi i.District i.Designation

reg `Asset'  _IDist*  if Batch==1 
predict LogTotal11 if Batch==1, resid
reg `Asset'  _IDist* $EmployeeControls if Batch==1 
predict LogTotal12 if Batch==1, resid
reg `Asset'  _IDist* if Batch==2  
predict LogTotal21 if Batch==2, resid
reg `Asset'  _IDist* $EmployeeControls if Batch==2  
predict LogTotal22 if Batch==2, resid
save "$Data/Bootstrap 2", replace

******************************** Bootstrapping ************************

set matsize 800
set seed 1984
global B=100

quietly{
forvalues b=1/$B{
	if mod(`b',$B/10)==0{
	local counter=round(`b'/$B*10)
	nois display "Done `counter'/10"
	}
	use "$Data/Bootstrap 1", clear
	bsample
	tempfile bootstrap
	save `bootstrap'

	use "$Data/Bootstrap 2", clear
	joinby BlockId using `bootstrap', unmatched(none)
	local counter=0
	forvalues x=.1(.1).9{
		local ++counter
		qreg LogTotal11 Treatment  if Batch==1, quantile(`x')  
		mat C11=e(b)
		qreg LogTotal12 Treatment  if Batch==1, quantile(`x')  
		mat C12=e(b)
		qreg LogTotal21 Treatment if Batch==2 , quantile(`x') 
		mat C21=e(b)
		qreg LogTotal22 Treatment if Batch==2 , quantile(`x') 
		mat C22=e(b)
		if `counter'==1{
			 mat B11=C11[1,1]
			 mat B21=C21[1,1]
			 mat B12=C12[1,1]
			 mat B22=C22[1,1]
		}
		else{
			 mat B11=B11,C11[1,1]
			 mat B21=B21,C21[1,1]
			 mat B12=B12,C12[1,1]
			 mat B22=B22,C22[1,1]
		}
	}
	if `b'==1 | `b'==501{
		mat A11=B11
		mat A21=B21
		mat A12=B12
		mat A22=B22
	}
	else{
		mat A11=A11\B11
		mat A21=A21\B21
		mat A12=A12\B12
		mat A22=A22\B22
	}
}
}
	clear
	svmat A11
	svmat A12
	svmat A21
	svmat A22
	order A11* A12* A21* A22*
	outsheet using "$Tables/Treatment Effect on `Asset' Assets Declared Quantile Bootstrap `Posting'.csv",replace comma

************************ Main Estimates **************************

use "$Data/Bootstrap 2", clear

*quietly{
local counter=0
forvalues x=.1(.1).9{
		local ++counter
qreg LogTotal11 Treatment  if Batch==1, quantile(`x')  
mat C11=e(b)
mat V11=e(V)
mat V11=sqrt(V11[1,1])
qreg LogTotal21 Treatment  if Batch==2 , quantile(`x') 
mat C21=e(b)
mat V21=e(V)
mat V21=sqrt(V21[1,1])
qreg LogTotal12 Treatment  if Batch==1, quantile(`x')  
mat C12=e(b)
mat V12=e(V)
mat V12=sqrt(V12[1,1])
qreg LogTotal22 Treatment  if Batch==2 , quantile(`x') 
mat C22=e(b)
mat V22=e(V)
mat V22=sqrt(V22[1,1])
mat E11=C11[1,1]\V11[1,1]
mat E21=C21[1,1]\V21[1,1]
mat E12=C12[1,1]\V12[1,1]
mat E22=C22[1,1]\V22[1,1]
if `counter'==1{
mat B11=E11
mat B21=E21
mat B12=E12
mat B22=E22
}
else{
mat B11=B11,E11
mat B21=B21,E21
mat B12=B12,E12
mat B22=B22,E22
}
}
mat A11=B11
mat A21=B21
mat A12=B12
mat A22=B22
*}

insheet using "$Tables/Treatment Effect on `Asset' Assets Declared Quantile Bootstrap `Posting'.csv",clear names case 
tempfile results
save `results'


clear 
svmat A11
svmat A12
svmat A21
svmat A22
order A11* A12* A21* A22*
append using `results'

foreach var of varlist A*{
scalar Coef=real(subinstr("`var'","A","",1))
scalar Estimate=`var'[1]
scalar SD1=`var'[2]
gen Diff`var'=Estimate-`var'
_pctile Diff`var' if _n>2, nq(1000)
scalar ub=Estimate-`r(r50)'
scalar lb=Estimate-`r(r950)'
quie su `var' if _n>2
scalar SD2=`r(sd)'
scalar ub2=Estimate+1.645*SD2
scalar lb2=Estimate-1.645*SD2
display "`var': " Estimate "(" SD2 ")" _newline ///
"CI1: " lb "to" ub _newline ///
"CI2: " lb2 "to" ub2
mat A=Coef\Estimate\SD1\SD2\ub\lb\ub2\lb2
if Coef==111{
	mat B=A
}
else{
	mat B=B,A
}
}
clear 
mat B=B'
svmat B

outsheet using "$Tables/Treatment Effect on `Asset' Assets Declared Quantile Bootstrap Final `Posting'.csv", comma names replace


}
}
