


use  "$Data/Sample Block GP with census info", replace
keep DistrictName_off BlockName_off PanchayatName_off CensusPCA2011_No_HH
rename *Name_off *

tempfile census
save `census'

use "$Data/MIS Job Cards Employment by Period", clear
drop if Period==1 
drop DaysPerWorkingHousehold
keep Payments Days PersonsWorking HouseholdsWorking Period DistrictName_off BlockName_off PanchayatName_off
reshape wide    Payments Days PersonsWorking HouseholdsWorking , ///
i(DistrictName_off BlockName_off PanchayatName_off) j(Period)

rename District District
rename Block Block
rename Panchayat Panchayat

tempfile MIS
save `MIS'

use "$Data/CPSMS Data by Period.dta", clear
drop if Period==1 
rename DistrictName District
rename BlockName Block
reshape wide    GPDebit GPCredit GPLastBalance , ///
i(District Block Panchayat) j(Period)

tempfile CPSMS
save `CPSMS'

use "$Data/Household Survey Clean Anonymized", clear

rename *WagesReceived* *Wages*
rename *DaysWorked* *Days*


rename *BeforeTreat *2
rename *DuringTreat1 *3
rename *DuringTreat2 *4
rename *DuringTreat *5
rename *SinceTreat *6

 drop  NREGAPaymentAdvance NREGADays NREGAWages

drop *Week* *C
collapse (mean) NREGAWorked*  NREGAPaymentAdvance* NREGADelayMinimum* $HHControls ///
  NREGADays* NREGAWages*   [aweight=PWeight], ///
 by(District Block Panchayat BlockId DistrictId Treatment)
 
 reshape long    NREGAWorked  NREGADays NREGAWages  , ///
i(District Block Panchayat BlockId DistrictId ) j(Period)
reshape wide    NREGAWorked  NREGADays NREGAWages , ///
i(District Block Panchayat BlockId DistrictId ) j(Period)

tempfile temp
save `temp'
*********************************************************
*********** Treatment effect on employment **************
*********************************************************

global Table="TA10 Leakages (Survey)"


use `temp', clear

merge 1:1 District Block Panchayat using `MIS',gen(_m1) keep( match)

merge 1:1 District Block Panchayat using `census',gen(_m3) keep( match)


collapse (mean) NREGAWorked* NREGADays*  NREGAWages* $HHControls  HouseholdsWorking* Payments* Days* CensusPCA2011_No_HH, ///
 by(District Block   BlockId DistrictId Treatment)

 forvalues period=2/6{
	gen LeakagesParticipation`period'=NREGAWorked`period'-HouseholdsWorking`period'/CensusPCA2011_No_HH 
	gen LeakagesDays`period'=NREGADays`period'-Days`period'/CensusPCA2011_No_HH 
	gen LeakagesWages`period'=NREGAWages`period'/1000-Payments`period'/CensusPCA2011_No_HH *100
 }
 
 local counter=0

quietly{
foreach outcome of  varlist  LeakagesDays? {

local ++counter
quie su `outcome' 
local ControlMean=`r(mean)'
xi: reg `outcome' Treatment i.DistrictId $HHControls , cluster(BlockId)
if `counter'==1 outreg2 Treatment using "$Tables/$Table",  replace  keep(Treatment) addtext(District FE, Yes, HH Controls, Yes, Weighted, No)  nonotes noaster nocons ///
adds("Mean in Control", `ControlMean')
else outreg2 Treatment using "$Tables/$Table",   keep(Treatment) addtext(District FE, Yes, HH Controls, Yes, Weighted, No)  nonotes noaster nocons ///
adds("Mean in Control", `ControlMean')
}
}



use `temp', clear

merge 1:1 District Block Panchayat using `CPSMS',gen(_m2) keep( match)

merge 1:1 District Block Panchayat using `census',gen(_m3) keep( match)


collapse (mean)  NREGAWages*  GPDebitAmount* $HHControls CensusPCA2011_No_HH, ///
 by(District Block   BlockId DistrictId Treatment)

 forvalues period=2/6{
	gen LeakagesWagesCPSMS`period'=NREGAWages`period'/1000-GPDebitAmount`period'/CensusPCA2011_No_HH*100 
	
 }
 
quietly{
foreach outcome of varlist  LeakagesWagesCPSMS?{

local ++counter
quie su `outcome' 
local ControlMean=`r(mean)'
xi: reg `outcome' Treatment i.DistrictId $HHControls , cluster(BlockId)
if `counter'==1 outreg2 Treatment using "$Tables/$Table",  replace  keep(Treatment) addtext(District FE, Yes, HH Controls, Yes, Weighted, No)  nonotes noaster nocons ///
adds("Mean in Control", `ControlMean')
else outreg2 Treatment using "$Tables/$Table",   keep(Treatment) addtext(District FE, Yes, HH Controls, Yes, Weighted, No)  nonotes noaster nocons ///
adds("Mean in Control", `ControlMean')
}
}

outreg2 Treatment using "$Tables/$Table",  excel keep(Treatment) addtext(District FE, Yes, HH Controls, Yes, Weighted, No)  nonotes noaster nocons ///
adds("Mean in Control", `ControlMean')

