


use "$Data/CPSMS Data by Year.dta", clear
tempfile cpsms
save `cpsms'


use "$Data/MIS Job Cards Employment by Year", clear
drop if Year==2010
drop if missing(BlockName_off) | missing(PanchayatName_off) | missing(DistrictName_off)
collapse (sum) JobCardExpenditures=Payments JobCardDays=Days, by(DistrictName_off BlockName_off PanchayatName_off Year) fast
tempfile jobcards
save `jobcards'



use "$Data/MIS Sample Data by Year", clear
collapse (sum) ExpLabour ExpMaterial Persondays_Total, by(Year Treatment DistrictName_off BlockName_off PanchayatName_off)
egen BlockId=group(DistrictName_off BlockName_off)
merge 1:1 DistrictName_off BlockName_off PanchayatName_off Year using `jobcards'
** All blocks are merged **
bys DistrictName_off BlockName_off: egen BlockMerge=max(_m)
tab BlockMerge _m
** 14 Panchayat in MIS and not in Jobcard
** 144 Panchayat with  data missing for some year in one data or the other ***
bys DistrictName_off BlockName_off PanchayatName_off: egen PanchayatMerge=max(_m)
egen PanchayatTag=tag(DistrictName_off BlockName_off PanchayatName_off)
tab PanchayatMerge _m if PanchayatTag
keep if _m==3
drop *Merge _m PanchayatTag
merge 1:1 DistrictName_off BlockName_off PanchayatName_off Year using `cpsms'
** All blocks are merged **
bys DistrictName_off BlockName_off: egen BlockMerge=max(_m)
tab BlockMerge _m
** 35 Panchayat in MIS and not in CPSMS
** 105 Panchayat in CPSMS and not in MIS
** 27 Panchayat with early data missing in CPSMS ***
bys DistrictName_off BlockName_off PanchayatName_off: egen PanchayatMerge=max(_m)
egen PanchayatTag=tag(DistrictName_off BlockName_off PanchayatName_off)
tab PanchayatMerge _m if PanchayatTag
keep if _m==3
drop *Merge _m PanchayatTag


replace JobCardExpenditures=JobCardExpenditures/100000
gen MISExpenditures=ExpLabour+ExpMaterial

*drop if MISExpenditures==0 | CPSMSExpenditures==0 | JobCardExpenditures==0

gen DiscrepancyCPSMSMIS=GPDebitAmount-MISExpenditures
gen DiscrepancyJCMIS=JobCardExpenditures-ExpLabour
gen DiscrepancyJCMISDays=JobCardDays-Persondays_Total

preserve
gen OUTVariable=""
gen OUTYear=.
gen OUTControl=.
gen OUTTreatment=.
gen OUTDiff=.
gen OUTPValue=.
local n=0
*quietly{
xi i.DistrictName_off
foreach var of varlist GPDebitAmount MISExpenditures DiscrepancyCPSMSMIS {
foreach year in 2011 2012 2013{
local ++n
replace OUTVariable="`var'" in `n'
replace OUTYear=`year' in `n'
reg `var' Treatment if Year==`year' & !missing(DiscrepancyCPSMSMIS), cluster(BlockId)
replace OUTControl=_b[_cons] in `n'
replace OUTTreatment=_b[_cons]+_b[Treatment] in `n'
replace OUTDiff=_b[Treatment] in `n'
replace OUTPValue= 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) in `n'
display 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) 
}
}
foreach var of varlist  JobCardExpenditures ExpLabour DiscrepancyJCMIS{
foreach year in 2011 2012 2013{
local ++n
replace OUTVariable="`var'" in `n'
replace OUTYear=`year' in `n'
reg `var' Treatment if Year==`year' & !missing(DiscrepancyJCMIS), cluster(BlockId)
replace OUTControl=_b[_cons] in `n'
replace OUTTreatment=_b[_cons]+_b[Treatment] in `n'
replace OUTDiff=_b[Treatment] in `n'
replace OUTPValue= 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) in `n'
display 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) 
}
}

foreach var of varlist  JobCardDays Persondays_Total DiscrepancyJCMISDays{
foreach year in 2011 2012 2013{
local ++n
replace OUTVariable="`var'" in `n'
replace OUTYear=`year' in `n'
reg `var' Treatment if Year==`year' & !missing(DiscrepancyJCMISDays), cluster(BlockId)
replace OUTControl=_b[_cons] in `n'
replace OUTTreatment=_b[_cons]+_b[Treatment] in `n'
replace OUTDiff=_b[Treatment] in `n'
replace OUTPValue= 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) in `n'
display 2*( 1-normal(abs(_b[Treatment]/_se[Treatment])) ) 
}
}
*}
drop if missing(OUTVariable)
keep OUT*
outsheet using "$Tables/TA2 Expenditures Comparison.csv", comma names replace
restore


